@@ -16,9 +16,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 # We will do simple option processing.  The calling syntax of this
 # program is:
@@ -498,9 +496,6 @@ my @preserve_vars = qw(TERM HOME LOGNAME PGPPATH GNUPGHOME GPG_AGENT_INFO
 	$arg eq '--tgz-check' and $tgz_check=1, next;
 	$arg =~ /^--no-?tgz-check$/ and $tgz_check=0, next;
 	$arg =~ /^-r(.*)/ and $root_command=$1, next;
-	if ($arg eq '--ignore-dirname') {
-	    fatal "--ignore-dirname has been replaced by --check-dirname-level and\n--check-dirname-regex; run $progname --help for more details";
-	}
 	if ($arg =~ /^--check-dirname-level=(.*)$/) {
 	    $arg = '--check-dirname-level';
 	    unshift @ARGV, $1;
@@ -654,6 +649,8 @@ my $pkg = $changelog{'Source'};
 fatal "no version number in changelog!"
     unless exists $changelog{'Version'};
 my $version = $changelog{'Version'};
+(my $sversion=$version) =~ s/^\d+://;
+(my $uversion=$sversion) =~ s/-[a-z0-9+\.]+$//i;
 
 # Is the directory name acceptable?
 if ($check_dirname_level ==  2 or
@@ -963,10 +960,9 @@ if ($command_version eq 'dpkg') {
 	/^(.*)=(.*)$/ and $ENV{$1} = $2;
     }
 
-    # We need to do the arch, sversion, pv, pva stuff to figure out
+    # We need to do the arch, pv, pva stuff to figure out
     # what the changes file will be called,
-    my ($sversion, $uversion, $dsc, $changes, $build);
-    my $arch;
+    my ($arch, $dsc, $changes, $build);
     if ($sourceonly) {
 	$arch = 'source';
     } else {
@@ -975,19 +971,18 @@ if ($command_version eq 'dpkg') {
 	fatal "couldn't determine host architecture!?" if ! $arch;
     }
 
-    ($sversion=$version) =~ s/^\d+://;
-    ($uversion=$sversion) =~ s/-[a-z0-9+\.]+$//i;
     $dsc = "${pkg}_${sversion}.dsc";
     my $orig_prefix = "${pkg}_${uversion}.orig.tar";
     my $origdir = basename(cwd()) . ".orig";
     if (! $binaryonly and $tgz_check and $uversion ne $sversion
 	and ! -f "../${orig_prefix}.bz2" and ! -f "../${orig_prefix}.lzma"
-	and ! -f "../${orig_prefix}.gz" and ! -d "../$origdir") {
+	and ! -f "../${orig_prefix}.gz" and ! -f "../${orig_prefix}.xz"
+	and ! -d "../$origdir") {
 	print STDERR "This package has a Debian revision number but there does"
 	    . " not seem to be\nan appropriate original tar file or .orig"
 	    . " directory in the parent directory;\n(expected one of"
-	    . " ${orig_prefix}.gz, ${orig_prefix}.bz2,\n${orig_prefix}.lzma or"
-	    . " $origdir)\ncontinue anyway? (y/n) ";
+	    . " ${orig_prefix}.gz, ${orig_prefix}.bz2,\n${orig_prefix}.lzma, "
+	    . " ${orig_prefix}.xz or $origdir)\ncontinue anyway? (y/n) ";
 	my $ans = <STDIN>;
 	exit 1 unless $ans =~ /^y/i;
     }
@@ -1354,7 +1349,7 @@ sub run_hook ($$) {
     print STDERR " Running $hook-hook\n";
     my $hookcmd = $hook{$hook};
     $act = $act ? 1 : 0;
-    my %per=("%"=>"%", "p"=>$pkg, "v"=>$version, "a"=>$act);
+    my %per=("%"=>"%", "p"=>$pkg, "v"=>$version, "s"=>$sversion, "u"=>$uversion, "a"=>$act);
     $hookcmd =~ s/\%(.)/exists $per{$1} ? $per{$1} :
 	(warn ("Unrecognised \% substitution in hook: \%$1\n"), "\%$1")/eg;
 
