@@ -18,8 +18,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # General Public License for more details.
 #
-# For a copy of the GNU General Public License write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 use 5.004;	# correct pipe close behavior
 use strict;
@@ -116,7 +116,7 @@ sub check_signature {
 
     my ($out, $err) = ('', '');
     eval {
-	fork_and_exec(exec => \@cmd,
+	spawn(exec => \@cmd,
 	    from_file => $file,
 	    to_string => \$out,
 	    error_to_string => \$err,
@@ -288,7 +288,7 @@ sub process_file {
 
 	my $this_sha1;
 	eval {
-	    fork_and_exec(exec => ['sha1sum', $filename],
+	    spawn(exec => ['sha1sum', $filename],
 		to_string => \$this_sha1,
 		wait_child => 1);
 	};
@@ -301,7 +301,7 @@ sub process_file {
 
 	my $this_sha256;
 	eval {
-	    fork_and_exec(exec => ['sha256sum', $filename],
+	    spawn(exec => ['sha256sum', $filename],
 		to_string => \$this_sha256,
 		wait_child => 1);
 	};
